@@ -47,9 +47,11 @@ class EmailConfiguration(TimeStampedModel):
 
     Subject = models.CharField(max_length=200, null=True)
 
-    Logo = models.ImageField(help_text="Please upload your logo here")
+    Logo = models.ImageField(upload_to='logo_pic', default='logo.jpg',
+                             help_text="Please upload your logo here")
 
-    Banner = models.ImageField(help_text="Please upload your banner here")
+    Banner = models.ImageField(upload_to='banner_pic', default='banner.jpg',
+                               help_text="Please upload your banner here")
 
     Log_path = models.CharField(max_length=200, null=True)
 
